<div><img src="https://raw.githubusercontent.com/myHBPwork/NMCog/master/resources/images/nmcogLogo4.png" alt="CerebUnit" height="23%" width="15%" align="right"></div>

# nmcog
Library for simulating cognitive models in neuromorphic platforms.

Current target platforms
- [SpiNNaker](http://spinnakermanchester.github.io/)

[nmcog documentation](https://nmcog.readthedocs.io/en/latest/)

<div><img src="https://raw.githubusercontent.com/myHBPwork/NMCog/master/resources/images/eu_logo.jpg" alt="EU Logo" height="23%" width="15%" align="right"></div>

### ACKNOWLEDGEMENTS
This open source software code was developed in part or in whole in the Human Brain Project, funded from the European Union’s Horizon 2020 Framework Programme for Research and Innovation under the Specific Grant Agreement No. 785907 (Human Brain Project SGA2).